@@ -25,9 +25,14 @@ try:
     try:
         from pymongo import MongoClient as Connection
         from pymongo import MongoReplicaSetClient as ReplicaSetConnection
+        from pymongo import version_tuple as pymongo_version
+        from bson import SON
     except ImportError:
         from pymongo import Connection
         from pymongo import ReplicaSetConnection
+        from pymongo import version_tuple as pymongo_version
+        from bson import SON
+
     from pymongo.errors import ConnectionFailure, AutoReconnect, OperationFailure, ConfigurationError
 except ImportError:
     raise ImportError("Can't import pymongo. See http://api.mongodb.org/python/current/ for instructions on how to install pymongo.")
@@ -299,6 +304,7 @@ class MLaunchTool(BaseCmdLineTool):
                     else:
                         print "adding shards."
 
+                shard_conns_and_names = zip(self.shard_connection_str, shard_names)
                 while True:
                     try:
                         nshards = con['config']['shards'].count()
@@ -307,9 +313,9 @@ class MLaunchTool(BaseCmdLineTool):
                     if nshards >= shards_to_add:
                         break
 
-                    for conn_str in self.shard_connection_str:
+                    for conn_str, name in shard_conns_and_names:
                         try:
-                            res = con['admin'].command({'addShard': conn_str})
+                            res = con['admin'].command( SON([('addShard', conn_str), ('name', name)]) )
                         except Exception as e:
                             if self.args['verbose']:
                                 print e, ', will retry in a moment.'
@@ -318,7 +324,7 @@ class MLaunchTool(BaseCmdLineTool):
                         if res['ok']:
                             if self.args['verbose']:
                                 print "shard %s added successfully"%conn_str
-                                self.shard_connection_str.remove(conn_str)
+                                shard_conns_and_names.remove( (conn_str, name) )
                                 break
                         else:
                             if self.args['verbose']:
@@ -1076,6 +1082,12 @@ class MLaunchTool(BaseCmdLineTool):
             con[database].add_user(name, password=password, roles=roles)
         except OperationFailure as e:
             pass
+        except TypeError as e:
+            if pymongo_version < (2, 5, 0):
+                con[database].add_user(name, password=password)
+                warnings.warn('Your pymongo version is too old to support auth roles. Added a legacy user with root access. To support roles, you need to upgrade to pymongo >= 2.5.0')
+            else: 
+                raise e
 
 
     def _get_processes(self):
@@ -1092,8 +1104,11 @@ class MLaunchTool(BaseCmdLineTool):
             for possible_port in self.startup_info:
                 # compare ports based on command line argument
                 startup = self.startup_info[possible_port].split()
-                p_port = p.cmdline[p.cmdline.index('--port')+1]
-                startup_port = startup[startup.index('--port')+1]
+                try:
+                    p_port = p.cmdline[p.cmdline.index('--port')+1]
+                    startup_port = startup[startup.index('--port')+1]
+                except ValueError:
+                    continue
 
                 if str(p_port) == str(startup_port):
                     port = int(possible_port)
