@@ -51,6 +51,7 @@ class MPlotQueriesTool(LogFileTool):
         self.plot_types = [c[1] for c in inspect.getmembers(plottypes, inspect.isclass)]
         self.plot_types = dict((pt.plot_type_str, pt) for pt in self.plot_types)
         self.plot_instances = []
+        self.plot_instance = None
 
         # main parser arguments
         self.argparser.add_argument('--logscale', action='store_true', help='plot y-axis in logarithmic scale (default=off)')
@@ -121,7 +122,7 @@ class MPlotQueriesTool(LogFileTool):
             multiple_files = True
             self.args['group'] = 'filename'
         
-        plot_instance = self.plot_types[self.args['type']](args=self.args, unknown_args=self.unknown_args)
+        self.plot_instance = self.plot_types[self.args['type']](args=self.args, unknown_args=self.unknown_args)
 
         for logfile in self.logfiles:
             
@@ -154,7 +155,7 @@ class MPlotQueriesTool(LogFileTool):
                     self.update_progress(float(progress_curr-progress_start) / progress_total, 'parsing %s'%logfile.name)
 
                 # offer plot_instance and see if it can plot it
-                if plot_instance.accept_line(logevent):
+                if self.plot_instance.accept_line(logevent):
                     
                     # if logevent doesn't have datetime, skip
                     if logevent.datetime == None:
@@ -163,7 +164,7 @@ class MPlotQueriesTool(LogFileTool):
                     if logevent.namespace == None:
                         logevent._namespace = "None"
 
-                    plot_instance.add_line(logevent)
+                    self.plot_instance.add_line(logevent)
 
                 if multiple_files:
                     # amend logevent object with filename for group by filename
@@ -171,13 +172,13 @@ class MPlotQueriesTool(LogFileTool):
 
 
             # store start and end for each logfile (also works for system.profile and stdin stream)
-            plot_instance.date_range = (logfile.start, logfile.end)
+            self.plot_instance.date_range = (logfile.start, logfile.end)
 
         # clear progress bar
         if self.logfiles and self.progress_bar_enabled:
             self.update_progress(1.0)
 
-        self.plot_instances.append(plot_instance)
+        self.plot_instances.append(self.plot_instance)
 
 
     def group(self):
@@ -268,7 +269,7 @@ class MPlotQueriesTool(LogFileTool):
             print "Deleted overlays."          
 
 
-    def print_shortcuts(self):
+    def print_shortcuts(self, scatter=False):
         print "\nkeyboard shortcuts (focus must be on figure window):\n"
 
         print "    %8s  %s" % ("p", "switch to pan mode")
@@ -280,6 +281,11 @@ class MPlotQueriesTool(LogFileTool):
         print "    %8s  %s" % ("1-9", "toggle visibility of top 10 individual plots 1-9")
         print "    %8s  %s" % ("0", "toggle visibility of all plots")
         print "    %8s  %s" % ("-", "toggle visibility of legend")
+        if scatter:
+            print "    %8s  %s" % ("[/]", "decrease / increase opacity by 10%")
+            print "    %8s  %s" % ("{/}", "decrease / increase opacity by 1%")
+            print "    %8s  %s" % ("</>", "decrease / increase marker size")
+            print "    %8s  %s" % ("e", "toggle marker edges")
         print "    %8s  %s" % ("g", "toggle grid")
         print "    %8s  %s" % ("c", "toggle 'created with' footnote")
         print "    %8s  %s" % ("s", "save figure")
@@ -319,6 +325,95 @@ class MPlotQueriesTool(LogFileTool):
             pass
 
 
+    def _init_opacities(self):
+        for artist in self.artists:
+            if not hasattr(artist, '_mt_opacity'):
+                artist._mt_opacity = artist.get_alpha()
+
+    def _any_opacities_to_increase(self):
+        for artist in self.artists:
+            if artist._mt_opacity < 0.99:
+                return True
+        return False
+
+    def _any_opacities_to_decrease(self):
+        for artist in self.artists:
+            if artist._mt_opacity > 0.01:
+                return True
+        return False
+
+    def set_opacities(self):
+        for artist in self.artists:
+            if artist._mt_opacity > 1.0:
+                artist.set_alpha(1.0)
+            elif artist._mt_opacity < 0.01:
+                artist.set_alpha(0.01)
+            else:
+                artist.set_alpha(artist._mt_opacity)
+
+    def increase_opacity(self, amount):
+        self._init_opacities()
+        if self._any_opacities_to_increase():
+            for artist in self.artists:
+                artist._mt_opacity = artist._mt_opacity + amount
+            self.set_opacities()
+
+    def decrease_opacity(self, amount):
+        self._init_opacities()
+        if self._any_opacities_to_decrease():
+            for artist in self.artists:
+                artist._mt_opacity = artist._mt_opacity - amount
+            self.set_opacities()
+
+    def toggle_marker_edges(self):
+        for artist in self.artists:
+            if artist.get_markeredgewidth() != 0:
+                artist._mt_markeredgewidth = artist.get_markeredgewidth()
+                artist.set_markeredgewidth(0)
+            else:
+                artist.set_markeredgewidth(artist._mt_markeredgewidth)
+
+    def _init_markersizes(self):
+        for artist in self.artists:
+            if not hasattr(artist, '_mt_markersize'):
+                artist._mt_markersize = artist.get_markersize()
+
+    def _any_markersizes_to_increase(self):
+        for artist in self.artists:
+            if artist._mt_markersize < 10.0:
+                return True
+        return False
+
+    def _any_markersizes_to_decrease(self):
+        for artist in self.artists:
+            if artist._mt_markersize > 1.0:
+                return True
+        return False
+
+    def set_markersizes(self):
+        for artist in self.artists:
+            if artist._mt_markersize > 10.0:
+                artist.set_markersize(10.0)
+            elif artist._mt_markersize < 1.01:
+                artist.set_markersize(1.0)
+            else:
+                artist.set_markersize(artist._mt_markersize)
+
+    def increase_marker_size(self, amount = 1):
+        self._init_markersizes()
+        if self._any_markersizes_to_increase():
+            for artist in self.artists:
+                artist._mt_markersize = artist._mt_markersize + amount
+            self.set_markersizes()
+
+    def decrease_marker_size(self, amount = 1):
+        self._init_markersizes()
+        if self._any_markersizes_to_decrease():
+            for artist in self.artists:
+                artist._mt_markersize = artist._mt_markersize - amount
+            self.set_markersizes()
+
+
     def onpress(self, event):
         # number keys
         if event.key in ['1', '2', '3', '4', '5', '6', '7', '8', '9']:
@@ -369,6 +464,38 @@ class MPlotQueriesTool(LogFileTool):
 
             plt.gcf().canvas.draw()
 
+        # opacity
+        if isinstance(self.plot_instance, plottypes.ScatterPlotType):
+            if event.key == '[':
+                self.decrease_opacity(0.10)
+                plt.gcf().canvas.draw()
+
+            if event.key == '{':
+                self.decrease_opacity(0.01)
+                plt.gcf().canvas.draw()
+
+            if event.key == ']':
+                self.increase_opacity(0.10)
+                plt.gcf().canvas.draw()
+
+            if event.key == '}':
+                self.increase_opacity(0.01)
+                plt.gcf().canvas.draw()
+
+            # edge on/off
+            if event.key == 'e':
+                self.toggle_marker_edges()
+                plt.gcf().canvas.draw()
+
+            # marker size
+            if event.key == '<':
+                self.decrease_marker_size()
+                plt.gcf().canvas.draw()
+
+            if event.key == '>':
+                self.increase_marker_size()
+                plt.gcf().canvas.draw()
+
 
     def plot(self):
         # check if there is anything to plot
@@ -395,7 +522,7 @@ class MPlotQueriesTool(LogFileTool):
         ylabel = ''
 
         # use timezone of first log file (may not always be what user wants but must make a choice)
-        tz = self.args['logfile'][0].timezone
+        tz = self.logfiles[0].timezone
         tzformat = '%b %d\n%H:%M:%S' if tz == tzutc() else '%b %d\n%H:%M:%S%z'
 
         locator = AutoDateLocator(tz=tz, minticks=5, maxticks=10)
@@ -421,7 +548,7 @@ class MPlotQueriesTool(LogFileTool):
             if hasattr(plot_inst, 'ylabel'):
                 ylabel = plot_inst.ylabel
         if self.args['output_file'] is None:
-            self.print_shortcuts()
+            self.print_shortcuts(scatter=isinstance(self.plot_instance, plottypes.ScatterPlotType))
 
         axis.set_xlabel(xlabel)
         axis.set_xticklabels(axis.get_xticks(), rotation=90, fontsize=9)
