@@ -67,7 +67,7 @@ class BaseCmdLineTool(object):
         # define argument parser and add version argument
         self.argparser = argparse.ArgumentParser()
         self.argparser.add_argument('--version', action='version', version="mtools version %s" % __version__)
-
+        self.argparser.add_argument('--no-progressbar', action='store_true', default=False, help='disables progress bar')
         self.is_stdin = not sys.stdin.isatty()
         
 
@@ -92,11 +92,16 @@ class BaseCmdLineTool(object):
             else:
                 self.args = vars(self.argparser.parse_args())
 
+        self.progress_bar_enabled = not (self.args['no_progressbar'] or self.is_stdin)
+
     
     def _datetime_to_epoch(self, dt):
         """ converts the datetime to unix epoch (properly). """
         if dt:
-            return int((dt - datetime.datetime.fromtimestamp(0, tzutc())).total_seconds())
+            td = (dt - datetime.datetime.fromtimestamp(0, tzutc()))
+            # don't use total_seconds(), that's only available in 2.7
+            total_secs = int((td.microseconds + (td.seconds + td.days * 24 * 3600) * 10**6) / 10**6)
+            return total_secs
         else: 
             return 0
     
