@@ -28,6 +28,9 @@ class LogEvent(object):
         thread: the thread name (e.g. "conn1234") as string
         operation: insert, update, remove, query, command, getmore, None
         namespace: the namespace of the operation, or None
+        command: the type of command, if the operation was a "command"
+        pattern: the query pattern for queries, updates, counts, etc
+        ...
 
         Certain operations also add the number of affected/scanned documents.
         If applicable, the following variables are also set, otherwise the
@@ -45,6 +48,21 @@ class LogEvent(object):
     months = ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', \
         'Oct', 'Nov', 'Dec']
 
+    log_operations = ['query', 'insert', 'update', 'remove', 'getmore', 'command']
+    log_levels = ['D', 'F', 'E', 'W', 'I', 'U']
+    log_components = ['-',
+                      'ACCESS',
+                      'COMMANDS',
+                      'INDEXING',
+                      'NETWORK',
+                      'QUERY',
+                      'REPLSETS',
+                      'SHARDING',
+                      'STORAGE',
+                      'JOURNAL',
+                      'WRITES',
+                      'S2',
+                      'TOTAL']
 
     def __init__(self, doc_or_str):
         self._year_rollover = False
@@ -86,6 +104,9 @@ class LogEvent(object):
         self._pattern = None
         self._sort_pattern = None
 
+        self._command_calculated = False
+        self._command = None
+
         self._counters_calculated = False
         self._nscanned = None
         self._ntoreturn = None
@@ -94,10 +115,15 @@ class LogEvent(object):
         self._ninserted = None
         self._ndeleted = None
         self._numYields = None
+        self._planSummary = None
         self._r = None
         self._w = None
         self._conn = None
 
+        self._level_calculated = False
+        self._level = None
+        self._component = None
+
         self.merge_marker_str = ''
 
     def set_line_str(self, line_str):
@@ -184,6 +210,10 @@ class LogEvent(object):
 
                     # separate datetime str and linestr
                     self._line_str = ' '.join(self.split_tokens[self._datetime_nextpos:])
+
+                    if self.level:
+                        self._datetime_nextpos += 2
+
                     self._reformat_timestamp(self._datetime_format)
                     break
 
@@ -356,7 +386,7 @@ class LogEvent(object):
 
         op = split_tokens[self._datetime_nextpos + 1]
 
-        if op in ['query', 'insert', 'update', 'remove', 'getmore', 'command']:
+        if op in self.log_operations:
             self._operation = op
             self._namespace = split_tokens[self._datetime_nextpos + 2]
 
@@ -369,7 +399,7 @@ class LogEvent(object):
         if not self._pattern:
 
             # trigger evaluation of operation
-            if self.operation in ['query', 'getmore', 'update', 'remove']:
+            if self.operation in ['query', 'getmore', 'update', 'remove'] or self.command in ['count', 'findandmodify']:
                 self._pattern = self._find_pattern('query: ')
 
         return self._pattern
@@ -388,6 +418,26 @@ class LogEvent(object):
         return self._sort_pattern
 
 
+    @property
+    def command(self):
+        """ extract query pattern from operations """
+        
+        if not self._command_calculated:
+
+            self._command_calculated = True
+            if self.operation == 'command':
+                try: 
+                    command_idx = self.split_tokens.index('command:')
+                    command = self.split_tokens[command_idx+1]
+                    if command == '{':
+                        # workaround for <= 2.2 log files, where command was not listed separately
+                        command = self.split_tokens[command_idx+2][:-1]
+                    self._command = command
+                except ValueError:
+                    pass
+
+        return self._command
+
     @property
     def nscanned(self):
         """ extract nscanned counter if available (lazy) """
@@ -460,6 +510,17 @@ class LogEvent(object):
 
         return self._numYields
 
+    @property
+    def planSummary(self):
+        """ extract numYields counter if available (lazy) """
+
+        if not self._counters_calculated:
+            self._counters_calculated = True
+            self._extract_counters()
+
+        return self._planSummary
+
+
     @property
     def r(self):
         """ extract read lock (r) counter if available (lazy) """
@@ -480,7 +541,6 @@ class LogEvent(object):
 
         return self._w
 
-
     def _extract_counters(self):
         """ Helper method to extract counters like nscanned, nreturned, etc.
             from the logevent.
@@ -488,7 +548,7 @@ class LogEvent(object):
 
         # extract counters (if present)
         counters = ['nscanned', 'ntoreturn', 'nreturned', 'ninserted', \
-            'nupdated', 'ndeleted', 'r', 'w', 'numYields']
+            'nupdated', 'ndeleted', 'r', 'w', 'numYields', 'planSummary']
 
         split_tokens = self.split_tokens
 
@@ -507,9 +567,44 @@ class LogEvent(object):
                                     self._numYields = int((split_tokens[t+1+self.datetime_nextpos+2]).replace(',', ''))
                                 except ValueError:
                                     pass
+                            if counter == 'planSummary' and token.startswith('planSummary'):
+                                try:
+                                    self._planSummary = split_tokens[t+1+self.datetime_nextpos+2]
+                                except ValueError:
+                                    pass
+
                         # token not parsable, skip
                         break
 
+    @property
+    def level(self):
+        """ extract log level if available (lazy) """
+        if not self._level_calculated:
+            self._level_calculated = True
+            self._extract_level()
+        return self._level
+
+    @property
+    def component(self):
+        """ extract log component if available (lazy) """
+        self.level
+        return self._component
+
+    def _extract_level(self):
+        """
+        extract level and component if available (lazy)
+        """
+
+        if self._level is None:
+            split_tokens = self.split_tokens
+            x = self.log_levels.index(split_tokens[1]) if split_tokens[1] in self.log_levels else None
+
+            if x is not None:
+                self._level = split_tokens[1]
+                self._component = split_tokens[2]
+            else:
+                self._level = False
+                self._component = False
 
 
     def parse_all(self):
@@ -561,7 +656,6 @@ class LogEvent(object):
             return None
 
 
-
     def _reformat_timestamp(self, format, force=False):
         if format not in ['ctime', 'ctime-pre2.4', 'iso8601-utc', 'iso8601-local']:
             raise ValueError('invalid datetime format %s, choose from ctime, ctime-pre2.4, iso8601-utc, iso8601-local.')
